--- ./config/sysv5.00	2008-11-26 12:41:55.000000000 -0800
+++ ./config/sysv5	2008-11-26 12:41:51.660000011 -0800
@@ -0,0 +1,92 @@
+/*
+ * config.h -- configure various defines for tcsh
+ *
+ * All source files should #include this FIRST.
+ *
+ * Edit this to match your system type.
+ */
+
+#ifndef _h_config
+#define _h_config
+/****************** System dependant compilation flags ****************/
+/*
+ * POSIX	This system supports IEEE Std 1003.1-1988 (POSIX).
+ */
+#define POSIX
+
+/*
+ * POSIXJOBS	This system supports the optional IEEE Std 1003.1-1988 (POSIX)
+ *		job control facilities.
+ */
+#define POSIXJOBS
+
+/*
+ * VFORK	This machine has a vfork().  
+ *		It used to be that for job control to work, this define
+ *		was mandatory. This is not the case any more.
+ *		If you think you still need it, but you don't have vfork, 
+ *		define this anyway and then do #define vfork fork.  
+ *		I do this anyway on a Sun because of yellow pages brain damage,
+ *		[should not be needed under 4.1]
+ *		and on the iris4d cause	SGI's fork is sufficiently "virtual" 
+ *		that vfork isn't necessary.  (Besides, SGI's vfork is weird).
+ *		Note that some machines eg. rs6000 have a vfork, but not
+ *		with the berkeley semantics, so we cannot use it there either.
+ */
+#define VFORK
+
+/*
+ * BSDJOBS	You have BSD-style job control (both process groups and
+ *		a tty that deals correctly
+ */
+#define BSDJOBS
+
+/*
+ * BSDTIMES	You have BSD-style process time stuff (like rusage)
+ *		This may or may not be true.  For example, Apple Unix
+ *		(OREO) has BSDJOBS but not BSDTIMES.
+ *		SVR4 has a dummy rusage structure, so we don't use it.
+ */
+#undef BSDTIMES
+
+/*
+ * BSDLIMIT	You have BSD-style resource limit stuff (getrlimit/setrlimit)
+ */
+#define BSDLIMIT
+
+/*
+ * TERMIO	You have struct termio instead of struct sgttyb.
+ * 		This is usually the case for SYSV systems, where
+ *		BSD uses sgttyb. POSIX systems should define this
+ *		anyway, even though they use struct termios.
+ */
+#define TERMIO
+
+/*
+ * SYSVREL	Your machine is SYSV based (HPUX, A/UX)
+ *		NOTE: don't do this if you are on a Pyramid -- tcsh is
+ *		built in a BSD universe.
+ *		Set SYSVREL to 1, 2, 3, or 4, depending on the version of SYSV
+ *		you are running, or set it to 0 if you are not SYSV based.
+ */
+#define SYSVREL	4
+
+/*
+ * YPBUGS	Work around Sun YP bugs that cause expansion of ~username
+ *		to send command output to /dev/null
+ */
+#undef YPBUGS
+
+/*
+ * ECHO_STYLE	Optionally change the behavior of the builtin echo
+ *		BOTH_ECHO: Support both bsd options (-n) and sysv escapes (\nnn)
+ *		BSD_ECHO:  Support only -n
+ *		SYSV_ECHO: Support only sysv escapes (\nnn)
+ *		NONE_ECHO: Pure echo.
+ */
+#define ECHO_STYLE BOTH_ECHO	/* BSD options only */
+
+/****************** local defines *********************/
+#define SCO
+
+#endif /* _h_config */
--- ./Configure-OSR6.00	2008-11-26 12:04:38.100000007 -0800
+++ ./Configure-OSR6	2008-11-26 12:49:35.460000011 -0800
@@ -0,0 +1,20 @@
+#!/bin/sh
+#
+HOST=i586-sco-sysv5
+CFLAGS="-O2"
+INSTALL=/usr/gnu/bin/install
+NM=nm-p
+M4=/usr/gnu/bin/m4
+if [ "$1" = "-g" ]
+then
+  CC="gcc -D_REENTRANT"
+  CXX="g++ -D_REENTRANT"
+  CFLAGS="$CFLAGS -Wall"
+else
+  CC="cc -Kpthread -Kalloca"
+  CXX="CC -Kpthread -Kalloca"
+fi
+export CC CXX CFLAGS NM M4 INSTALL
+rm -f mout-configure
+./configure --prefix=/usr/local --mandir=/usr/local/man \
+            --host=$HOST --target=$HOST --build=$HOST 2>&1 | tee mout-configure
--- ./configure.in.00	2008-10-09 10:46:31.000000000 -0700
+++ ./configure.in	2008-11-26 12:43:44.800000021 -0800
@@ -183,6 +183,11 @@
     DFLAGS="$DFLAGS -DDELL"
   ;;
 
+  ## SVR5 (SCO OpenServer 6 and UnixWare 7)
+  *-*-sysv5* )
+    tcsh_config_file=sysv5
+  ;;
+
   ## SVR4 (Generic and otherwise)
   *-*-sysv4* )
     tcsh_config_file=sysv4
--- ./configure.00	2008-10-09 10:47:18.000000000 -0700
+++ ./configure	2008-11-26 12:44:08.860000114 -0800
@@ -2006,6 +2006,11 @@
     DFLAGS="$DFLAGS -DDELL"
   ;;
 
+  ## SVR5 (SCO OpenServer 6 and UnixWare 7)
+  *-*-sysv5* )
+    tcsh_config_file=sysv5
+  ;;
+
   ## SVR4 (Generic and otherwise)
   *-*-sysv4* )
     tcsh_config_file=sysv4
--- ./Install-OSR6.00	2008-11-26 12:44:56.720000003 -0800
+++ ./Install-OSR6	2008-11-26 12:48:08.790000011 -0800
@@ -0,0 +1,13 @@
+#!/bin/sh
+
+MOUT=mout-install
+D=/u/tmp/tcsh
+DESTDIR=$D
+export DESTDIR
+
+[ -f $MOUT ] && mv $MOUT $MOUT-prev
+[ -d $D ] && rm -rf $D
+mkdir -p $D
+make install DESTDIR=$D 2>&1 | tee $MOUT
+make install.man DESTDIR=$D 2>&1 | tee $MOUT-man
+
